@@ -77,12 +77,13 @@ class FileManagementUtility:
             logging.debug('No Tickets returned for the named reference')
             return result
 
-        ticket = next(iter(file_read_tickets.tickets.values()))
-        ticket_uids = cls.fcc.register_tickets([ticket])
-        try:
-            cls.fcc.download_file_to_location("IMD", ticket_uids[0], parent_dir, file_name)
-        finally:
-            cls.fcc.unregister_tickets(ticket_uids)
+        ticket = next(iter(file_read_tickets.tickets.values())) if file_read_tickets.tickets else None
+        if ticket:
+            ticket_uids = cls.fcc.register_tickets([ticket])
+            try:
+                cls.fcc.download_file_to_location("IMD", ticket_uids[0], parent_dir, file_name)
+            finally:
+                cls.fcc.unregister_tickets(ticket_uids)
         return result
 
     @classmethod
@@ -96,13 +97,14 @@ class FileManagementUtility:
         partial_errors = file_read_tickets.serviceData.partialErrors
         if partial_errors is None:
             partial_errors = list()
-        tickets = file_read_tickets.tickets.values()
-        ticket_uids = cls.fcc.register_tickets(tickets)
-        try:
-            file_names = [e.file_name for e in get_file_entries]
-            cls.fcc.download_files_to_location("IMD", ticket_uids, destination_dir, file_names)
-        finally:
-            cls.fcc.unregister_tickets(ticket_uids)
+        tickets = file_read_tickets.tickets.values() if file_read_tickets.tickets else list()
+        if tickets:
+            ticket_uids = cls.fcc.register_tickets(tickets)
+            try:
+                file_names = [e.file_name for e in get_file_entries]
+                cls.fcc.download_files_to_location("IMD", ticket_uids, destination_dir, file_names)
+            finally:
+                cls.fcc.unregister_tickets(ticket_uids)
         return partial_errors
 
     @classmethod
