@@ -1,6 +1,6 @@
 from tcsoa.gen.Allocations._2007_01.services import AllocationService as imp0
 from tcsoa.gen.Allocations._2011_06.services import AllocationService as imp1
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class AllocationService(TcService):
