@@ -2,7 +2,7 @@ from tcsoa.gen.ChangeManagement._2008_06.services import ChangeManagementService
 from tcsoa.gen.ChangeManagement._2015_10.services import ChangeManagementService as imp1
 from tcsoa.gen.ChangeManagement._2020_01.services import ChangeManagementService as imp2
 from tcsoa.gen.ChangeManagement._2009_06.services import ChangeManagementService as imp3
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class ChangeManagementService(TcService):
