@@ -1,22 +1,22 @@
 from __future__ import annotations
 
 from tcsoa.gen.BusinessObjects import BusinessObject
-from typing import Dict, List
-from tcsoa.gen.Internal.Core._2017_11.LogicalObject import PresentedPropertyDefinition
+from typing import List
+from tcsoa.gen.Server import ServiceData
 from tcsoa.base import TcBaseObj
 from dataclasses import dataclass
 
 
 @dataclass
-class LogicalObjectTypeInput2(TcBaseObj):
+class LogicalObjectTypeInput(TcBaseObj):
     """
     Holds the logical object type definition data for the specified logical object type to be created.
     
     :var name: Name of the logical object type. (user supplied name)
     :var displayName: Display name of the logical object type.
     :var description: Description of the logical object type.
-    :var rootTypeName: Name of the root business object, All subtypes of POM_object are supported.
-    :var parentTypeName: Name of the parent logical object type, It should be a type or subtype of Fnd0LogicalObject.
+    :var rootTypeName: Name of the root business object, , All subtypes of POM_object are supported.
+    :var parentTypeName: Name of the parent logical object type, It should be a type or subtype of Fnd0LogicalObject. 
     (optional)
     :var retrieveClassificationData: If TRUE , classification data will be retrieved for the root business object.
     If FALSE , classification data will not be retrieved for the root business object.
@@ -29,12 +29,24 @@ class LogicalObjectTypeInput2(TcBaseObj):
     rootTypeName: str = ''
     parentTypeName: str = ''
     retrieveClassificationData: bool = False
-    memberPropertyDefinitions: List[MemberPropertyDefinition2] = ()
+    memberPropertyDefinitions: List[MemberPropertyDefinition] = ()
     presentedPropertyDefinitions: List[PresentedPropertyDefinition] = ()
 
 
 @dataclass
-class MemberPropertyDefinition2(TcBaseObj):
+class LogicalObjectTypeResponse(TcBaseObj):
+    """
+    Holds the list of the created logical object types and partial errors.
+    
+    :var loTypes: A list of the created logical object types.
+    :var serviceData: Returned service data.
+    """
+    loTypes: List[BusinessObject] = ()
+    serviceData: ServiceData = None
+
+
+@dataclass
+class MemberPropertyDefinition(TcBaseObj):
     """
     Member properties represents the objects, which is reached from the root business object via the specified
     traversal paths, in order to present their properties onto the logical object.
@@ -49,65 +61,82 @@ class MemberPropertyDefinition2(TcBaseObj):
     memberPropertyName: str = ''
     displayName: str = ''
     description: str = ''
-    traversalPath: List[TraversalHop2] = ()
+    traversalPath: List[TraversalHop] = ()
     retrieveClassificationData: bool = False
 
 
 @dataclass
-class TraversalHop2(TcBaseObj):
+class PresentedPropertyDefinition(TcBaseObj):
     """
-    Represents traversal hop definition for "forward" or "reverse" traversal on either a relation property or a
-    reference property.
+    Presented properties represents the actual source properties of a root or member object on the logical object.
+    
+    :var presentedPropertyName: Name of the presented property.
+    :var displayName: Display name of the presented property.
+    :var description: Description of the presented property.
+    :var rootOrMemberName: Root business object name or member property name.
+    :var sourcePropertyName: Name of the source property of root or member business object.
+    """
+    presentedPropertyName: str = ''
+    displayName: str = ''
+    description: str = ''
+    rootOrMemberName: str = ''
+    sourcePropertyName: str = ''
+
+
+@dataclass
+class TraversalHop(TcBaseObj):
+    """
+    Holds traversal hop information which is represented either as a relation property (GRM, GRMS2P) or reference
+    property (REF, REFBY).
     
     :var propertyName: Source object property name.
     :var propertyType: Type of property. Supported values are "relation" or "reference".
-    :var destinationType: Type of destination object. All subtypes of POM_object are supported.
+    :var destinationType: Type of destination object.
     :var direction: Direction of traversal. Supported values are "forward" or "reverse".
-    :var destinationObjectCriteria: It represents the criteria expression. The destination objects that satisfy the
-    criteria expression will be returned. By default, destination object criteria expression is empty. Supported values
-    are
-    1.    $CurrentUserSessionProject, which is a system-defined criteria expression for traversal to the  destination
-    objects which are assigned to the current user session project. (optional)
     """
     propertyName: str = ''
     propertyType: str = ''
     destinationType: str = ''
     direction: str = ''
-    destinationObjectCriteria: str = ''
 
 
 @dataclass
-class UpdateMemberInput(TcBaseObj):
+class AddMemberAndPresentedPropsResponse(TcBaseObj):
     """
-    Represents the definition data for members that is to be updated on an existing Logical Object Type.
+    Holds the output list of defined member and/or presented properties that were created on the specified logical
+    object type and any partial errors, if thrown.
     
-    :var logicalObjectType: An object of logical object type ( subtype of "Fnd0LogicalObject" ) to which member
-    definitions are being updated.
-    :var membersToBeUpdated: A map (string, MemberPropertyDefinition2) of name of member and it's definition which is
-    to be updated.
-    Key for this map would be a existing "member name" and value a structure which contains the new definition for this
-    member.
+    :var memberOrPresentedProps: List of defined member and/or presented properties that were created on the specified
+    input logical object type.
+    :var serviceData: Returned service data.
     """
-    logicalObjectType: BusinessObject = None
-    membersToBeUpdated: MemberDefinitionMap = None
+    memberOrPresentedProps: List[BusinessObject] = ()
+    serviceData: ServiceData = None
 
 
 @dataclass
-class AddMembersPresentedPropsInput2(TcBaseObj):
+class AddMembersPresentedPropsInput(TcBaseObj):
     """
-    Represents the definition data for member and presented properties to be added to an existing Logical Object Type.
+    Holds the member and presented properties definition data on the specified logical object type.
     
     :var logicalObjectType: An object of logical object type ( subtype of "Fnd0LogicalObject" ) to which members and
     presented properties are to be added.
-    :var memberPropertiesDefinitions: A list of member defintions.
+    :var memberDefinitions: A list of member defintions.
     :var presentedPropertiesDefinitions: A list of presented property defintions.
     """
     logicalObjectType: BusinessObject = None
-    memberPropertiesDefinitions: List[MemberPropertyDefinition2] = ()
+    memberDefinitions: List[MemberPropertyDefinition] = ()
     presentedPropertiesDefinitions: List[PresentedPropertyDefinition] = ()
 
 
-"""
-A map of member and it's member definition information.
-"""
-MemberDefinitionMap = Dict[str, MemberPropertyDefinition2]
+@dataclass
+class DeleteMembersPresentedPropsInput(TcBaseObj):
+    """
+    Holds the logical object type and the member and presented properties on the specified logical object type.
+    
+    :var logicalObject: An object of type "Fnd0LogicalObject" for which members and presented properties are to be
+    deleted.
+    :var memberIdsOrPresentedProps: A list of member ids or presented property names.
+    """
+    logicalObject: BusinessObject = None
+    memberIdsOrPresentedProps: List[str] = ()
