@@ -1,6 +1,6 @@
 from tcsoa.gen.Internal_DocMgmtAw._2019_06.services import DocMgmtService as imp0
 from tcsoa.gen.Internal_DocMgmtAw._2019_12.services import DocMgmtService as imp1
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class DocMgmtService(TcService):
