@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 from tcsoa.gen.Internal.Gdis._2006_03.Reporting import PrecalRoutineInfoResponse
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class ReportingService(TcService):
