@@ -1,5 +1,5 @@
 from tcsoa.gen.Notification._2014_10.services import SubscriptionManagementService as imp0
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class SubscriptionManagementService(TcService):
