@@ -1,7 +1,7 @@
 from tcsoa.gen.RelationshipViewer._2012_10.services import NetworkEngineService as imp0
 from tcsoa.gen.RelationshipViewer._2014_11.services import NetworkEngineService as imp1
 from tcsoa.gen.RelationshipViewer._2019_12.services import NetworkEngineService as imp2
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class NetworkEngineService(TcService):
