@@ -4,7 +4,7 @@ from tcsoa.gen.Requirementsmanagement._2008_06.services import RequirementsManag
 from tcsoa.gen.Requirementsmanagement._2010_09.services import RequirementsManagementService as imp3
 from tcsoa.gen.Requirementsmanagement._2009_10.services import RequirementsManagementService as imp4
 from tcsoa.gen.Requirementsmanagement._2011_06.services import RequirementsManagementService as imp5
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class RequirementsManagementService(TcService):
